<?php
/**
 * x-blog Theme Customizer
 *
 * @package x-blog
 */
//Sanitize layout
function x_blog_sanitize_layout($value){ 
	if(!in_array($value, array('right-sidebar','left-sidebar','full-width'))){
		$value = 'right-sidebar';
	}
	return $value;
}

//Sanitize layout
function x_blog_sanitize_theme_color($value){ 
	if(!in_array($value, array('theme-black','theme-green','theme-blue'))){
		$value = 'theme-black';
	}
	return $value;
}
//Sanitize logo
function x_blog_logo_position($value){ 
	if(!in_array($value, array('logo-right','logo-left','logo-center'))){
		$value = 'logo-center';
	}
	return $value;
}

//Sanitize footer text
function x_blog_sanitize_footer_text($value){ 
	if(empty($value)){
		$value = '<a href="'.esc_url( __( 'https://wordpress.org/', 'x-blog' ) ).'">'.esc_html__( 'Proudly powered by WordPress', 'x-blog' ).'</a> <span class="sep"> | </span>'.esc_html__('Theme: X Blog by', 'x-blog').' <a href="'.esc_url('http://nalam.awesomebootstrap.net').'">'.esc_html__('Noor Alam','x-blog').'</a>';
	}
	return $value;
}
/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function x_blog_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'x_blog_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'x_blog_customize_partial_blogdescription',
		) );
	}
	// Add x-blog options section
	$wp_customize->add_section('x_blog_options', array(
		'title' => __('X Blog Options', 'x-blog'),
		'capability'     => 'edit_theme_options',
		'description'     => __('The x Blog theme options ', 'x-blog'),

	));
	/*
	* Create header background color
	*/
	// Add setting
	$wp_customize->add_setting('header_bgcolor', array(
		'default' => '#fff',
		'type' =>'theme_mod',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport' => 'postMessage',
	));
	// Add color control 
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, 'header_bgcolor', array(
				'label' => __('Header Background Color','x-blog'),
				'section' => 'colors'
			)
		)
	);

	// Add setting
	$wp_customize->add_setting('content_bg_color', array(
		'default' => '#ededed',
		'type' =>'theme_mod',
		'sanitize_callback' => 'sanitize_hex_color',
		'transport' => 'postMessage',
	));
	// Add color control 
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize, 'content_bg_color', array(
				'label' => __('Content Background Color','x-blog'),
				'section' => 'colors'
			)
		)
	);
	  /*
	  * Logo position 
	   */
    $wp_customize->add_setting('logo_position', array(
        'default'        => 'logo-center',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'x_blog_logo_position',
        'transport' => 'postMessage',
    ));
    $wp_customize->add_control('logo_position_control', array(
        'label'      => __('Select logo position', 'x-blog'),
        'section'    => 'x_blog_options',
        'settings'   => 'logo_position',
        'type'       => 'radio',
        'choices'    => array(
            'logo-left' => __('Logo left', 'x-blog'),
            'logo-center' => __('Logo center', 'x-blog'),
            'logo-right' => __('Logo right', 'x-blog'),
        ),
    ));

	  /*
	  * Theme Color
	   */
      
    $wp_customize->add_setting('theme_color', array(
        'default'        => 'theme-black',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'x_blog_sanitize_theme_color',
        'transport' => 'postMessage',
    ));
    $wp_customize->add_control('theme_color_control', array(
        'label'      => __('Select Theme color', 'x-blog'),
        'section'    => 'x_blog_options',
        'settings'   => 'theme_color',
        'type'       => 'select',
        'choices'    => array(
            'theme-black' => __('Theme Black', 'x-blog'),
            'theme-green' => __('Theme Green', 'x-blog'),
            'theme-blue' => __('Theme Blue', 'x-blog'),
            'theme-indigo' => __('Theme Indigo', 'x-blog'),
            'theme-brown' => __('Theme Brown', 'x-blog'),
            'theme-bluegrey' => __('Theme Blue Grey', 'x-blog'),

        ),
    ));

    // Theme layout
     $wp_customize->add_setting('theme_layout', array(
        'default'        => 'right-sidebar',
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'x_blog_sanitize_layout',
        'transport' => 'postMessage',
    ));
    $wp_customize->add_control('layout_control', array(
        'label'      => __('Select Theme layout', 'x-blog'),
        'section'    => 'x_blog_options',
        'settings'   => 'theme_layout',
        'type'       => 'select',
        'choices'    => array(
            'right-sidebar' => __('Right Sidebar', 'x-blog'),
            'left-sidebar' => __('Left Sidebar', 'x-blog'),
            'full-width' => __('No Sidebar', 'x-blog'),
        ),
    ));
  
    // Footer text change
     $wp_customize->add_setting('footer_text', array(
        'capability'     => 'edit_theme_options',
        'type'           => 'theme_mod',
        'sanitize_callback' => 'x_blog_sanitize_footer_text',
        'transport' => 'postMessage',
    ));
    $wp_customize->add_control('footer_text_control', array(
        'label'      => __('Footer text', 'x-blog'),
        'description'     => __('Html tag support the field. You can see full HTML result after save text.', 'x-blog'),
        'section'    => 'x_blog_options',
        'settings'   => 'footer_text',
        'type'       => 'textarea',
    ));
  

    

}
add_action( 'customize_register', 'x_blog_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function x_blog_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function x_blog_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function x_blog_customize_preview_js() {
	wp_enqueue_script( 'x-blog-customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'x_blog_customize_preview_js' );
